# sky130ph

Skywater photonics PDK for the SKY130 process node.
https://byucamacholab.github.io/sky130ph/

## Installation

As of now, this PDK is not on PyPI.

So, to install it, you would need to:

1. Clone the repo
2. cd into the repo
3. Run `pip install -e .`

## TODO

- Add component library
- Add tests
- Test components

## Authors

- Skandan Chandrasekar
- Sequoia Ploeg
- Elise Bangerter
- Joel Kartchner
